import Button from '@material-ui/core/Button'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { EcogestureStepForm, ProfileTypeStepForm, SgeStep } from 'enums'
import React, { useCallback } from 'react'
import { useNavigate } from 'react-router-dom'
import './formNavigation.scss'

interface FormNavigationProps {
  step: ProfileTypeStepForm | EcogestureStepForm | SgeStep
  handlePrevious: () => void
  handleNext: () => void
  disableNextButton: boolean
  disablePrevButton?: boolean
  isEcogesture?: boolean
  isLastConnectStep?: boolean
  isLoading?: boolean
}

const FormNavigation = ({
  step,
  handlePrevious,
  handleNext,
  disableNextButton,
  disablePrevButton,
  isEcogesture,
  isLastConnectStep,
  isLoading,
}: FormNavigationProps) => {
  const { t } = useI18n()
  const navigate = useNavigate()
  const handlePreviousClick = () => {
    handlePrevious()
  }
  const handleNextClick = () => {
    handleNext()
    // handle go back to connect for SGE
    if (isLastConnectStep) {
      navigate('/consumption/electricity')
    }
  }

  const getSecondButtonLabel = useCallback(() => {
    if (isLoading) {
      return t('profile_type.form.button_loading')
    } else if (
      isLastConnectStep ||
      step === ProfileTypeStepForm.UPDATE_DATE ||
      (step === EcogestureStepForm.EQUIPMENTS && isEcogesture)
    ) {
      return t('profile_type.form.button_end')
    } else {
      return t('profile_type.form.button_next')
    }
  }, [isEcogesture, isLastConnectStep, isLoading, step, t])

  return (
    <div className="profile-navigation">
      <Button
        aria-label={t('profile_type.accessibility.button_previous')}
        onClick={handlePreviousClick}
        className="btnSecondary"
        disabled={
          disablePrevButton || step === ProfileTypeStepForm.HOUSING_TYPE
        }
      >
        {t('profile_type.form.button_previous')}
      </Button>
      <Button
        aria-label={
          step === ProfileTypeStepForm.UPDATE_DATE ||
          (step === EcogestureStepForm.EQUIPMENTS && isEcogesture)
            ? t('profile_type.accessibility.button_end')
            : t('profile_type.accessibility.button_next')
        }
        onClick={handleNextClick}
        className="btnPrimary"
        disabled={disableNextButton}
      >
        {getSecondButtonLabel()}
      </Button>
    </div>
  )
}

export default FormNavigation
