import { IconButton } from '@material-ui/core'
import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import Bill from 'assets/icons/ico/bill.svg'
import CloseIcon from 'assets/icons/ico/close.svg'
import Prm from 'assets/icons/ico/prm.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React from 'react'

interface SgeModalHintProps {
  open: boolean
  handleCloseClick: () => void
}

const SgeModalHint = ({ open, handleCloseClick }: SgeModalHintProps) => {
  const { t } = useI18n()

  return (
    <Dialog
      open={open}
      disableEscapeKeyDown
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('challenge_no_fluid_modal.accessibility.window_title')}
      </div>
      <IconButton
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
        onClick={handleCloseClick}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="sgeHintModal">
        <div className="title text-20-bold">
          {t('auth.enedissgegrandlyon.modalHint.title')}
        </div>
        <div className="pdl">
          <p>{t('auth.enedissgegrandlyon.pdlModal.txt1')}</p>
          <p>{t('auth.enedissgegrandlyon.pdlModal.txt2')}</p>
          <div className="bill">
            <Icon icon={Bill} alt="Facture" className="bill" />
            <p>{t('auth.enedissgegrandlyon.pdlModal.txt3')}</p>
          </div>
          <p>{t('auth.enedissgegrandlyon.pdlModal.txt4')}</p>
          <Icon icon={Prm} alt="PDL" className="prm" />
        </div>
        <Button
          aria-label={t(
            'auth.enedissgegrandlyon.modalHint.button-accessibility'
          )}
          onClick={handleCloseClick}
          className="btnPrimary"
        >
          {t('auth.enedissgegrandlyon.modalHint.button')}
        </Button>
      </div>
    </Dialog>
  )
}

export default SgeModalHint
