import { render, screen, waitFor } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import EcogestureTabsView from 'components/Ecogesture/EcogestureTabsView'
import React from 'react'
import { Provider } from 'react-redux'
import * as profileActions from 'store/profile/profile.slice'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'

const mockGetAllEcogestures = jest.fn()
jest.mock('services/ecogesture.service', () => {
  return jest.fn(() => ({
    getAllEcogestures: mockGetAllEcogestures,
    getEcogestureListByProfile: jest.fn().mockResolvedValue([]),
    initEcogesture: jest.fn().mockResolvedValue(mockedEcogesturesData),
  }))
})
jest.mock('services/profile.service', () => {
  return jest.fn(() => ({
    getProfile: jest.fn(),
    updateProfile: jest.fn(),
  }))
})

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock(
  'components/Ecogesture/EcogestureList/EcogestureList',
  () => 'mock-ecogesturelist'
)
jest.mock('components/Content/Content', () => 'mock-content')

jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useLocation: () => ({
    search: '',
  }),
  useNavigate: () => jest.fn(),
}))

describe('EcogestureView component', () => {
  const store = createMockEcolyoStore()

  it('should be rendered correctly', async () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureTabsView />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(screen.getAllByRole('button').length).toBe(3)
    expect(container).toMatchSnapshot()
  })

  it('should render ecogesture init modal', async () => {
    const updateProfileSpy = jest.spyOn(profileActions, 'updateProfile')

    const { container } = render(
      <Provider store={store}>
        <EcogestureTabsView />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(screen.getByRole('dialog')).toBeInTheDocument()
    await userEvent.click(screen.getAllByRole('button')[0])
    expect(updateProfileSpy).toHaveBeenCalledWith({
      haveSeenEcogestureModal: true,
    })
  })

  it('should render empty list', async () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureTabsView />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(
      container.getElementsByClassName('ec-empty-container').length
    ).toBeTruthy()
  })

  it('should change tab', async () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureTabsView />
      </Provider>
    )
    await waitFor(() => null, { container })
    await userEvent.click(screen.getAllByRole('button')[1])
    mockGetAllEcogestures.mockResolvedValueOnce([])
    await waitFor(() => null, { container })
    expect(
      container.getElementsByClassName('ec-empty-container').length
    ).toBeTruthy()
  })
})
