import { render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import * as storeHooks from 'store/hooks'
import { mockProfileEcogesture } from 'tests/__mocks__/profileEcogesture.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import EcogestureFormView from './EcogestureFormView'

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')
jest.mock(
  'components/EcogestureForm/EcogestureLaunchFormModal/EcogestureLaunchFormModal',
  () => 'mock-ecogesturelaunchmodal'
)

const mockAppDispatch = jest.spyOn(storeHooks, 'useAppDispatch')
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
  useLocation: () => ({
    search: '',
  }),
}))

describe('EcogestureFormView component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should be rendered correctly', async () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    expect(container).toMatchSnapshot()
  })
  it('should render singleChoice', async () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    expect(
      container.getElementsByClassName('ecogesture-form-single').length
    ).toBeTruthy()
  })
  it('should render profiletype form step because profiletype is completed', async () => {
    const store = createMockEcolyoStore({
      profile: { isProfileTypeCompleted: true },
      profileEcogesture: mockProfileEcogesture,
    })
    const { container } = render(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    expect(
      container.getElementsByClassName('profile-type-container').length
    ).toBeTruthy()
  })
  it('should go to next step', async () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    // await waitFor(() => null, { container })
    await userEvent.click(screen.getAllByRole('radio')[0])
    await userEvent.click(screen.getAllByRole('button')[1])
    expect(
      container.getElementsByClassName('ecogesture-form-single').length
    ).toBeTruthy()
  })
  it('should go to previous step', async () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )

    const [, next] = screen.getAllByRole('button')
    await userEvent.click(screen.getAllByRole('radio')[0])
    await userEvent.click(next)

    expect(
      container.getElementsByClassName('ecogesture-form-single').length
    ).toBeTruthy()
  })

  it('should handle form end', async () => {
    mockAppDispatch.mockReturnValue(jest.fn())
    jest
      .spyOn(React, 'useState')
      .mockImplementationOnce(() => [0, () => null])
      .mockImplementationOnce(() => [4, () => null])
    render(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    expect(mockAppDispatch).toHaveBeenCalledTimes(2)
  })
})
