import { Button, IconButton } from '@material-ui/core'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import exportDone from 'assets/icons/ico/exportDone.svg'
import warnCross from 'assets/icons/ico/warn-cross.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React from 'react'
import './exportDoneModal.scss'

interface ExportDoneModalProps {
  open: boolean
  error: boolean
  handleCloseClick: () => void
}

const ExportDoneModal = ({
  open,
  error,
  handleCloseClick,
}: ExportDoneModalProps) => {
  const { t } = useI18n()

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('export.modal_done.accessibility_title')}
      </div>

      <div className="modal-done-root">
        <IconButton
          aria-label={t('export.button_close')}
          className="modal-paper-close-button"
          onClick={handleCloseClick}
        >
          <Icon icon={CloseIcon} size={18} />
        </IconButton>

        <div className="content">
          <div className="icon-main">
            <Icon icon={error ? warnCross : exportDone} size={44} />
          </div>
          {!error && (
            <>
              <div className="text-16-bold subtitle">
                {t('export.modal_done.text1')}
              </div>
              <div>{t('export.modal_done.text2')}</div>
            </>
          )}
          {error && (
            <>
              <div className="text-20-bold error1">
                {t('export.modal_done.error1')}
              </div>
              <div className="text-16-bold">
                {t('export.modal_done.error2')}
              </div>
            </>
          )}

          <Button
            aria-label={t('export.modal_done.button_close')}
            onClick={handleCloseClick}
            className="btnPrimary"
          >
            {error
              ? t('export.modal_done.button_close_error')
              : t('export.modal_done.button_close')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default ExportDoneModal
